# SLC02 - Development Methodologies

Các phương pháp phát triển phần mềm: Waterfall, Agile, DevOps.

## Best Practices

| # | Best Practice | Mô tả |
|---|---------------|-------|
| BP01 | [Agile & Scrum](SLC02-BP01-Agile-Scrum.md) | Frameworks Agile và Scrum |
| BP02 | [DevOps Culture](SLC02-BP02-DevOps-Culture.md) | Văn hóa và practices DevOps |

## Tham khảo

- Agile Manifesto
- Scrum Guide
- DevOps Handbook
